/*******************************************************************************
* File Name: FIFOIn_1.h  
* Version 1.0
*
* Description:
* This component provides a convenient interface from programmable hardware to
* the CPU or DMA.  That interface is implemented using the 4-entry FIFO in the
* UDB.
*
********************************************************************************
* Copyright (2010), Cypress Semiconductor Corporation.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress) and is 
* protected by and subject to worldwide patent protection (United States and 
* foreign), United States copyright laws and international treaty provisions. 
* Cypress hereby grants to licensee a personal, non-exclusive, non-transferable 
* license to copy, use, modify, create derivative works of, and compile the 
* Cypress Source Code and derivative works for the sole purpose of creating 
* custom software in support of licensee product to be used only in conjunction 
* with a Cypress integrated circuit as specified in the applicable agreement. 
* Any reproduction, modification, translation, compilation, or representation of 
* this software except as specified above is prohibited without the express 
* written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH 
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the 
* materials described herein. Cypress does not assume any liability arising out 
* of the application or use of any product or circuit described herein. Cypress 
* does not authorize its products for use as critical components in life-support 
* systems where a malfunction or failure may reasonably be expected to result in 
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of 
* such use and in doing so indemnifies Cypress against all charges. Use may be 
* limited by and subject to the applicable Cypress software license agreement. 
*******************************************************************************/

#if !defined(FIFOIN_FIFOIn_1_H)
#define FIFOIN_FIFOIn_1_H

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h"

/*************************************** 
*   Conditional Compilation Parameters
***************************************/

#define FIFOIn_1_BUS_WIDTH (8u)

/* PSoC3 ES2 or early */
#define FIFOIn_1_PSOC3_ES2   ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A) && \
                                      (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_3A_ES2))
                     
/* PSoC5 ES1 */
#define FIFOIn_1_PSOC5_ES1   ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A) && \
                                      (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_5A_ES1)) 

/***************************************
*     Data Struct Definitions
***************************************/

/* Sleep Mode API Support */
typedef struct _FIFOIn_1_backupStruct
{
    uint8 enableState;
    
    #if (FIFOIn_1_PSOC3_ES2 || FIFOIn_1_PSOC5_ES1)
        uint8 IntMask;
    #endif /* (FIFOIn_1_PSOC3_ES2 || FIFOIn_1_PSOC5_ES1) */    
} FIFOIn_1_BACKUP_STRUCT;

/***************************************
*    Initial Parameter Constants        
***************************************/
#define FIFOIn_1_LVL_SETTING 	(0 ? FIFOIn_1_FIFO_LVL : 0)

/***************************************
*       Register Constants              
***************************************/
#define FIFOIn_1_EN           (0x01u)

#define FIFOIn_1_FIFO_CLR 	(1 << 0)
#define FIFOIn_1_FIFO_LVL 	(1 << 2)

#define FIFOIn_1_ST_MASK   (0x02u)

/***************************************
*             Registers                 
***************************************/
#define FIFOIn_1_CONTROL_REG      (* (reg8 *) FIFOIn_1_SyncCtl_ControlReg__CONTROL_REG)
#if (FIFOIn_1_BUS_WIDTH == 8u)
	#define FIFOIn_1_LSB_AUX_CONTROL_REG  (* (reg8 *) FIFOIn_1_Single_singleDP__DP_AUX_CTL_REG)
#else
	#define FIFOIn_1_LSB_AUX_CONTROL_REG  (* (reg8 *) FIFOIn_1_Dual_lsbDP__DP_AUX_CTL_REG)
	#define FIFOIn_1_MSB_AUX_CONTROL_REG  (* (reg8 *) FIFOIn_1_Dual_msbDP__DP_AUX_CTL_REG)
#endif
#define FIFOIn_1_STATUS_REG       (* (reg8 *) FIFOIn_1_StsReg__STATUS_REG)
#define FIFOIn_1_STATUS_MASK_REG  (* (reg8 *) FIFOIn_1_StsReg__MASK_REG)

#if (FIFOIn_1_BUS_WIDTH == 8u)
	#define FIFOIn_1_FIFO_PTR	((reg8 *) FIFOIn_1_Single_singleDP__F0_REG)
	#define FIFOIn_1_FIFO_REG  	(*(reg8 *) FIFOIn_1_Single_singleDP__F0_REG)
#else
	#define FIFOIn_1_FIFO_PTR	((reg8 *) FIFOIn_1_Dual_lsbDP__F0_REG)
	#define FIFOIn_1_FIFO_REG  	(*(reg8 *) FIFOIn_1_Dual_lsbDP__F0_REG)
	#define FIFOIn_1_FIFO16_PTR	((reg16 *) FIFOIn_1_Dual_lsbDP__16BIT_F0_REG)
#endif

/***************************************
*           API Constants               
***************************************/
#define FIFOIn_1_FIFO_OVERFLOW        (0x01u)
#define FIFOIn_1_FIFO_NOT_EMPTY       (0x02u)

/***************************************
 *   Function Prototypes
 **************************************/
void FIFOIn_1_Start(void)           ;
void FIFOIn_1_Stop(void)            ;
void FIFOIn_1_Enable(void)          ;
void FIFOIn_1_Init(void)            ;
void FIFOIn_1_Disable(void)         ;
void FIFOIn_1_ClearFIFO(void)       ;
#if (FIFOIn_1_BUS_WIDTH == 8u)
	uint8 FIFOIn_1_Read(void)           ;
#else
	uint16 FIFOIn_1_Read(void)           ;
#endif
uint8 FIFOIn_1_ReadStatus(void) ;
void FIFOIn_1_SetInterruptMode(uint8 interruptSource) ;
void FIFOIn_1_SaveConfig(void) ;
void FIFOIn_1_RestoreConfig(void) ;
void FIFOIn_1_Sleep(void) ;
void FIFOIn_1_Wakeup(void) ;

#endif  /* FIFOIN_FIFOIn_1_H */
