/*******************************************************************************
* File Name: Kbd3_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "Kbd3.h"

/* Check for removal by optimization */
#if !defined(Kbd3_Sync_ctrl_reg__REMOVED)

static Kbd3_BACKUP_STRUCT  Kbd3_backup = {0u};

    
/*******************************************************************************
* Function Name: Kbd3_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Kbd3_SaveConfig(void) 
{
    Kbd3_backup.controlState = Kbd3_Control;
}


/*******************************************************************************
* Function Name: Kbd3_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void Kbd3_RestoreConfig(void) 
{
     Kbd3_Control = Kbd3_backup.controlState;
}


/*******************************************************************************
* Function Name: Kbd3_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Kbd3_Sleep(void) 
{
    Kbd3_SaveConfig();
}


/*******************************************************************************
* Function Name: Kbd3_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Kbd3_Wakeup(void)  
{
    Kbd3_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
