/*******************************************************************************
* File Name: Kbd5_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "Kbd5.h"

/* Check for removal by optimization */
#if !defined(Kbd5_Sync_ctrl_reg__REMOVED)

static Kbd5_BACKUP_STRUCT  Kbd5_backup = {0u};

    
/*******************************************************************************
* Function Name: Kbd5_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Kbd5_SaveConfig(void) 
{
    Kbd5_backup.controlState = Kbd5_Control;
}


/*******************************************************************************
* Function Name: Kbd5_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void Kbd5_RestoreConfig(void) 
{
     Kbd5_Control = Kbd5_backup.controlState;
}


/*******************************************************************************
* Function Name: Kbd5_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Kbd5_Sleep(void) 
{
    Kbd5_SaveConfig();
}


/*******************************************************************************
* Function Name: Kbd5_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Kbd5_Wakeup(void)  
{
    Kbd5_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
