/*******************************************************************************
* File Name: NMIgen.h
* Version 3.30
*
* Description:
*  Contains the prototypes and constants for the functions available to the
*  PWM user module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_PWM_NMIgen_H)
#define CY_PWM_NMIgen_H

#include "cyfitter.h"
#include "cytypes.h"
#include "CyLib.h" /* For CyEnterCriticalSection() and CyExitCriticalSection() functions */

extern uint8 NMIgen_initVar;


/***************************************
* Conditional Compilation Parameters
***************************************/
#define NMIgen_Resolution                     (8u)
#define NMIgen_UsingFixedFunction             (0u)
#define NMIgen_DeadBandMode                   (0u)
#define NMIgen_KillModeMinTime                (0u)
#define NMIgen_KillMode                       (0u)
#define NMIgen_PWMMode                        (0u)
#define NMIgen_PWMModeIsCenterAligned         (0u)
#define NMIgen_DeadBandUsed                   (0u)
#define NMIgen_DeadBand2_4                    (0u)

#if !defined(NMIgen_PWMUDB_genblk8_stsreg__REMOVED)
    #define NMIgen_UseStatus                  (1u)
#else
    #define NMIgen_UseStatus                  (0u)
#endif /* !defined(NMIgen_PWMUDB_genblk8_stsreg__REMOVED) */

#if !defined(NMIgen_PWMUDB_genblk1_ctrlreg__REMOVED)
    #define NMIgen_UseControl                 (1u)
#else
    #define NMIgen_UseControl                 (0u)
#endif /* !defined(NMIgen_PWMUDB_genblk1_ctrlreg__REMOVED) */

#define NMIgen_UseOneCompareMode              (1u)
#define NMIgen_MinimumKillTime                (1u)
#define NMIgen_EnableMode                     (0u)

#define NMIgen_CompareMode1SW                 (0u)
#define NMIgen_CompareMode2SW                 (0u)

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component PWM_v3_30 requires cy_boot v3.0 or later
#endif /* (CY_ PSOC5LP) */

/* Use Kill Mode Enumerated Types */
#define NMIgen__B_PWM__DISABLED 0
#define NMIgen__B_PWM__ASYNCHRONOUS 1
#define NMIgen__B_PWM__SINGLECYCLE 2
#define NMIgen__B_PWM__LATCHED 3
#define NMIgen__B_PWM__MINTIME 4


/* Use Dead Band Mode Enumerated Types */
#define NMIgen__B_PWM__DBMDISABLED 0
#define NMIgen__B_PWM__DBM_2_4_CLOCKS 1
#define NMIgen__B_PWM__DBM_256_CLOCKS 2


/* Used PWM Mode Enumerated Types */
#define NMIgen__B_PWM__ONE_OUTPUT 0
#define NMIgen__B_PWM__TWO_OUTPUTS 1
#define NMIgen__B_PWM__DUAL_EDGE 2
#define NMIgen__B_PWM__CENTER_ALIGN 3
#define NMIgen__B_PWM__DITHER 5
#define NMIgen__B_PWM__HARDWARESELECT 4


/* Used PWM Compare Mode Enumerated Types */
#define NMIgen__B_PWM__LESS_THAN 1
#define NMIgen__B_PWM__LESS_THAN_OR_EQUAL 2
#define NMIgen__B_PWM__GREATER_THAN 3
#define NMIgen__B_PWM__GREATER_THAN_OR_EQUAL_TO 4
#define NMIgen__B_PWM__EQUAL 0
#define NMIgen__B_PWM__FIRMWARE 5



/***************************************
* Data Struct Definition
***************************************/


/**************************************************************************
 * Sleep Wakeup Backup structure for PWM Component
 *************************************************************************/
typedef struct
{

    uint8 PWMEnableState;

    #if(!NMIgen_UsingFixedFunction)
        uint8 PWMUdb;               /* PWM Current Counter value  */
        #if(!NMIgen_PWMModeIsCenterAligned)
            uint8 PWMPeriod;
        #endif /* (!NMIgen_PWMModeIsCenterAligned) */
        #if (NMIgen_UseStatus)
            uint8 InterruptMaskValue;   /* PWM Current Interrupt Mask */
        #endif /* (NMIgen_UseStatus) */

        /* Backup for Deadband parameters */
        #if(NMIgen_DeadBandMode == NMIgen__B_PWM__DBM_256_CLOCKS || \
            NMIgen_DeadBandMode == NMIgen__B_PWM__DBM_2_4_CLOCKS)
            uint8 PWMdeadBandValue; /* Dead Band Counter Current Value */
        #endif /* deadband count is either 2-4 clocks or 256 clocks */

        /* Backup Kill Mode Counter*/
        #if(NMIgen_KillModeMinTime)
            uint8 PWMKillCounterPeriod; /* Kill Mode period value */
        #endif /* (NMIgen_KillModeMinTime) */

        /* Backup control register */
        #if(NMIgen_UseControl)
            uint8 PWMControlRegister; /* PWM Control Register value */
        #endif /* (NMIgen_UseControl) */

    #endif /* (!NMIgen_UsingFixedFunction) */

}NMIgen_backupStruct;


/***************************************
*        Function Prototypes
 **************************************/

void    NMIgen_Start(void) ;
void    NMIgen_Stop(void) ;

#if (NMIgen_UseStatus || NMIgen_UsingFixedFunction)
    void  NMIgen_SetInterruptMode(uint8 interruptMode) ;
    uint8 NMIgen_ReadStatusRegister(void) ;
#endif /* (NMIgen_UseStatus || NMIgen_UsingFixedFunction) */

#define NMIgen_GetInterruptSource() NMIgen_ReadStatusRegister()

#if (NMIgen_UseControl)
    uint8 NMIgen_ReadControlRegister(void) ;
    void  NMIgen_WriteControlRegister(uint8 control)
          ;
#endif /* (NMIgen_UseControl) */

#if (NMIgen_UseOneCompareMode)
   #if (NMIgen_CompareMode1SW)
       void    NMIgen_SetCompareMode(uint8 comparemode)
               ;
   #endif /* (NMIgen_CompareMode1SW) */
#else
    #if (NMIgen_CompareMode1SW)
        void    NMIgen_SetCompareMode1(uint8 comparemode)
                ;
    #endif /* (NMIgen_CompareMode1SW) */
    #if (NMIgen_CompareMode2SW)
        void    NMIgen_SetCompareMode2(uint8 comparemode)
                ;
    #endif /* (NMIgen_CompareMode2SW) */
#endif /* (NMIgen_UseOneCompareMode) */

#if (!NMIgen_UsingFixedFunction)
    uint8   NMIgen_ReadCounter(void) ;
    uint8 NMIgen_ReadCapture(void) ;

    #if (NMIgen_UseStatus)
            void NMIgen_ClearFIFO(void) ;
    #endif /* (NMIgen_UseStatus) */

    void    NMIgen_WriteCounter(uint8 counter)
            ;
#endif /* (!NMIgen_UsingFixedFunction) */

void    NMIgen_WritePeriod(uint8 period)
        ;
uint8 NMIgen_ReadPeriod(void) ;

#if (NMIgen_UseOneCompareMode)
    void    NMIgen_WriteCompare(uint8 compare)
            ;
    uint8 NMIgen_ReadCompare(void) ;
#else
    void    NMIgen_WriteCompare1(uint8 compare)
            ;
    uint8 NMIgen_ReadCompare1(void) ;
    void    NMIgen_WriteCompare2(uint8 compare)
            ;
    uint8 NMIgen_ReadCompare2(void) ;
#endif /* (NMIgen_UseOneCompareMode) */


#if (NMIgen_DeadBandUsed)
    void    NMIgen_WriteDeadTime(uint8 deadtime) ;
    uint8   NMIgen_ReadDeadTime(void) ;
#endif /* (NMIgen_DeadBandUsed) */

#if ( NMIgen_KillModeMinTime)
    void NMIgen_WriteKillTime(uint8 killtime) ;
    uint8 NMIgen_ReadKillTime(void) ;
#endif /* ( NMIgen_KillModeMinTime) */

void NMIgen_Init(void) ;
void NMIgen_Enable(void) ;
void NMIgen_Sleep(void) ;
void NMIgen_Wakeup(void) ;
void NMIgen_SaveConfig(void) ;
void NMIgen_RestoreConfig(void) ;


/***************************************
*         Initialization Values
**************************************/
#define NMIgen_INIT_PERIOD_VALUE          (207u)
#define NMIgen_INIT_COMPARE_VALUE1        (191u)
#define NMIgen_INIT_COMPARE_VALUE2        (63u)
#define NMIgen_INIT_INTERRUPTS_MODE       (uint8)(((uint8)(0u <<   \
                                                    NMIgen_STATUS_TC_INT_EN_MASK_SHIFT)) | \
                                                    (uint8)((uint8)(0u <<  \
                                                    NMIgen_STATUS_CMP2_INT_EN_MASK_SHIFT)) | \
                                                    (uint8)((uint8)(0u <<  \
                                                    NMIgen_STATUS_CMP1_INT_EN_MASK_SHIFT )) | \
                                                    (uint8)((uint8)(0u <<  \
                                                    NMIgen_STATUS_KILL_INT_EN_MASK_SHIFT )))
#define NMIgen_DEFAULT_COMPARE2_MODE      (uint8)((uint8)1u <<  NMIgen_CTRL_CMPMODE2_SHIFT)
#define NMIgen_DEFAULT_COMPARE1_MODE      (uint8)((uint8)3u <<  NMIgen_CTRL_CMPMODE1_SHIFT)
#define NMIgen_INIT_DEAD_TIME             (1u)


/********************************
*         Registers
******************************** */

#if (NMIgen_UsingFixedFunction)
   #define NMIgen_PERIOD_LSB              (*(reg16 *) NMIgen_PWMHW__PER0)
   #define NMIgen_PERIOD_LSB_PTR          ( (reg16 *) NMIgen_PWMHW__PER0)
   #define NMIgen_COMPARE1_LSB            (*(reg16 *) NMIgen_PWMHW__CNT_CMP0)
   #define NMIgen_COMPARE1_LSB_PTR        ( (reg16 *) NMIgen_PWMHW__CNT_CMP0)
   #define NMIgen_COMPARE2_LSB            (0x00u)
   #define NMIgen_COMPARE2_LSB_PTR        (0x00u)
   #define NMIgen_COUNTER_LSB             (*(reg16 *) NMIgen_PWMHW__CNT_CMP0)
   #define NMIgen_COUNTER_LSB_PTR         ( (reg16 *) NMIgen_PWMHW__CNT_CMP0)
   #define NMIgen_CAPTURE_LSB             (*(reg16 *) NMIgen_PWMHW__CAP0)
   #define NMIgen_CAPTURE_LSB_PTR         ( (reg16 *) NMIgen_PWMHW__CAP0)
   #define NMIgen_RT1                     (*(reg8 *)  NMIgen_PWMHW__RT1)
   #define NMIgen_RT1_PTR                 ( (reg8 *)  NMIgen_PWMHW__RT1)

#else
   #if (NMIgen_Resolution == 8u) /* 8bit - PWM */

       #if(NMIgen_PWMModeIsCenterAligned)
           #define NMIgen_PERIOD_LSB      (*(reg8 *)  NMIgen_PWMUDB_sP8_pwmdp_u0__D1_REG)
           #define NMIgen_PERIOD_LSB_PTR  ((reg8 *)   NMIgen_PWMUDB_sP8_pwmdp_u0__D1_REG)
       #else
           #define NMIgen_PERIOD_LSB      (*(reg8 *)  NMIgen_PWMUDB_sP8_pwmdp_u0__F0_REG)
           #define NMIgen_PERIOD_LSB_PTR  ((reg8 *)   NMIgen_PWMUDB_sP8_pwmdp_u0__F0_REG)
       #endif /* (NMIgen_PWMModeIsCenterAligned) */

       #define NMIgen_COMPARE1_LSB        (*(reg8 *)  NMIgen_PWMUDB_sP8_pwmdp_u0__D0_REG)
       #define NMIgen_COMPARE1_LSB_PTR    ((reg8 *)   NMIgen_PWMUDB_sP8_pwmdp_u0__D0_REG)
       #define NMIgen_COMPARE2_LSB        (*(reg8 *)  NMIgen_PWMUDB_sP8_pwmdp_u0__D1_REG)
       #define NMIgen_COMPARE2_LSB_PTR    ((reg8 *)   NMIgen_PWMUDB_sP8_pwmdp_u0__D1_REG)
       #define NMIgen_COUNTERCAP_LSB      (*(reg8 *)  NMIgen_PWMUDB_sP8_pwmdp_u0__A1_REG)
       #define NMIgen_COUNTERCAP_LSB_PTR  ((reg8 *)   NMIgen_PWMUDB_sP8_pwmdp_u0__A1_REG)
       #define NMIgen_COUNTER_LSB         (*(reg8 *)  NMIgen_PWMUDB_sP8_pwmdp_u0__A0_REG)
       #define NMIgen_COUNTER_LSB_PTR     ((reg8 *)   NMIgen_PWMUDB_sP8_pwmdp_u0__A0_REG)
       #define NMIgen_CAPTURE_LSB         (*(reg8 *)  NMIgen_PWMUDB_sP8_pwmdp_u0__F1_REG)
       #define NMIgen_CAPTURE_LSB_PTR     ((reg8 *)   NMIgen_PWMUDB_sP8_pwmdp_u0__F1_REG)

   #else
        #if(CY_PSOC3) /* 8-bit address space */
            #if(NMIgen_PWMModeIsCenterAligned)
               #define NMIgen_PERIOD_LSB      (*(reg16 *) NMIgen_PWMUDB_sP8_pwmdp_u0__D1_REG)
               #define NMIgen_PERIOD_LSB_PTR  ((reg16 *)  NMIgen_PWMUDB_sP8_pwmdp_u0__D1_REG)
            #else
               #define NMIgen_PERIOD_LSB      (*(reg16 *) NMIgen_PWMUDB_sP8_pwmdp_u0__F0_REG)
               #define NMIgen_PERIOD_LSB_PTR  ((reg16 *)  NMIgen_PWMUDB_sP8_pwmdp_u0__F0_REG)
            #endif /* (NMIgen_PWMModeIsCenterAligned) */

            #define NMIgen_COMPARE1_LSB       (*(reg16 *) NMIgen_PWMUDB_sP8_pwmdp_u0__D0_REG)
            #define NMIgen_COMPARE1_LSB_PTR   ((reg16 *)  NMIgen_PWMUDB_sP8_pwmdp_u0__D0_REG)
            #define NMIgen_COMPARE2_LSB       (*(reg16 *) NMIgen_PWMUDB_sP8_pwmdp_u0__D1_REG)
            #define NMIgen_COMPARE2_LSB_PTR   ((reg16 *)  NMIgen_PWMUDB_sP8_pwmdp_u0__D1_REG)
            #define NMIgen_COUNTERCAP_LSB     (*(reg16 *) NMIgen_PWMUDB_sP8_pwmdp_u0__A1_REG)
            #define NMIgen_COUNTERCAP_LSB_PTR ((reg16 *)  NMIgen_PWMUDB_sP8_pwmdp_u0__A1_REG)
            #define NMIgen_COUNTER_LSB        (*(reg16 *) NMIgen_PWMUDB_sP8_pwmdp_u0__A0_REG)
            #define NMIgen_COUNTER_LSB_PTR    ((reg16 *)  NMIgen_PWMUDB_sP8_pwmdp_u0__A0_REG)
            #define NMIgen_CAPTURE_LSB        (*(reg16 *) NMIgen_PWMUDB_sP8_pwmdp_u0__F1_REG)
            #define NMIgen_CAPTURE_LSB_PTR    ((reg16 *)  NMIgen_PWMUDB_sP8_pwmdp_u0__F1_REG)
        #else
            #if(NMIgen_PWMModeIsCenterAligned)
               #define NMIgen_PERIOD_LSB      (*(reg16 *) NMIgen_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
               #define NMIgen_PERIOD_LSB_PTR  ((reg16 *)  NMIgen_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
            #else
               #define NMIgen_PERIOD_LSB      (*(reg16 *) NMIgen_PWMUDB_sP8_pwmdp_u0__16BIT_F0_REG)
               #define NMIgen_PERIOD_LSB_PTR  ((reg16 *)  NMIgen_PWMUDB_sP8_pwmdp_u0__16BIT_F0_REG)
            #endif /* (NMIgen_PWMModeIsCenterAligned) */

            #define NMIgen_COMPARE1_LSB       (*(reg16 *) NMIgen_PWMUDB_sP8_pwmdp_u0__16BIT_D0_REG)
            #define NMIgen_COMPARE1_LSB_PTR   ((reg16 *)  NMIgen_PWMUDB_sP8_pwmdp_u0__16BIT_D0_REG)
            #define NMIgen_COMPARE2_LSB       (*(reg16 *) NMIgen_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
            #define NMIgen_COMPARE2_LSB_PTR   ((reg16 *)  NMIgen_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
            #define NMIgen_COUNTERCAP_LSB     (*(reg16 *) NMIgen_PWMUDB_sP8_pwmdp_u0__16BIT_A1_REG)
            #define NMIgen_COUNTERCAP_LSB_PTR ((reg16 *)  NMIgen_PWMUDB_sP8_pwmdp_u0__16BIT_A1_REG)
            #define NMIgen_COUNTER_LSB        (*(reg16 *) NMIgen_PWMUDB_sP8_pwmdp_u0__16BIT_A0_REG)
            #define NMIgen_COUNTER_LSB_PTR    ((reg16 *)  NMIgen_PWMUDB_sP8_pwmdp_u0__16BIT_A0_REG)
            #define NMIgen_CAPTURE_LSB        (*(reg16 *) NMIgen_PWMUDB_sP8_pwmdp_u0__16BIT_F1_REG)
            #define NMIgen_CAPTURE_LSB_PTR    ((reg16 *)  NMIgen_PWMUDB_sP8_pwmdp_u0__16BIT_F1_REG)
        #endif /* (CY_PSOC3) */

       #define NMIgen_AUX_CONTROLDP1          (*(reg8 *)  NMIgen_PWMUDB_sP8_pwmdp_u1__DP_AUX_CTL_REG)
       #define NMIgen_AUX_CONTROLDP1_PTR      ((reg8 *)   NMIgen_PWMUDB_sP8_pwmdp_u1__DP_AUX_CTL_REG)

   #endif /* (NMIgen_Resolution == 8) */

   #define NMIgen_COUNTERCAP_LSB_PTR_8BIT ( (reg8 *)  NMIgen_PWMUDB_sP8_pwmdp_u0__A1_REG)
   #define NMIgen_AUX_CONTROLDP0          (*(reg8 *)  NMIgen_PWMUDB_sP8_pwmdp_u0__DP_AUX_CTL_REG)
   #define NMIgen_AUX_CONTROLDP0_PTR      ((reg8 *)   NMIgen_PWMUDB_sP8_pwmdp_u0__DP_AUX_CTL_REG)

#endif /* (NMIgen_UsingFixedFunction) */

#if(NMIgen_KillModeMinTime )
    #define NMIgen_KILLMODEMINTIME        (*(reg8 *)  NMIgen_PWMUDB_sKM_killmodecounterdp_u0__D0_REG)
    #define NMIgen_KILLMODEMINTIME_PTR    ((reg8 *)   NMIgen_PWMUDB_sKM_killmodecounterdp_u0__D0_REG)
    /* Fixed Function Block has no Kill Mode parameters because it is Asynchronous only */
#endif /* (NMIgen_KillModeMinTime ) */

#if(NMIgen_DeadBandMode == NMIgen__B_PWM__DBM_256_CLOCKS)
    #define NMIgen_DEADBAND_COUNT         (*(reg8 *)  NMIgen_PWMUDB_sDB255_deadbandcounterdp_u0__D0_REG)
    #define NMIgen_DEADBAND_COUNT_PTR     ((reg8 *)   NMIgen_PWMUDB_sDB255_deadbandcounterdp_u0__D0_REG)
    #define NMIgen_DEADBAND_LSB_PTR       ((reg8 *)   NMIgen_PWMUDB_sDB255_deadbandcounterdp_u0__A0_REG)
    #define NMIgen_DEADBAND_LSB           (*(reg8 *)  NMIgen_PWMUDB_sDB255_deadbandcounterdp_u0__A0_REG)
#elif(NMIgen_DeadBandMode == NMIgen__B_PWM__DBM_2_4_CLOCKS)
    
    /* In Fixed Function Block these bits are in the control blocks control register */
    #if (NMIgen_UsingFixedFunction)
        #define NMIgen_DEADBAND_COUNT         (*(reg8 *)  NMIgen_PWMHW__CFG0)
        #define NMIgen_DEADBAND_COUNT_PTR     ((reg8 *)   NMIgen_PWMHW__CFG0)
        #define NMIgen_DEADBAND_COUNT_MASK    (uint8)((uint8)0x03u << NMIgen_DEADBAND_COUNT_SHIFT)

        /* As defined by the Register Map as DEADBAND_PERIOD[1:0] in CFG0 */
        #define NMIgen_DEADBAND_COUNT_SHIFT   (0x06u)
    #else
        /* Lower two bits of the added control register define the count 1-3 */
        #define NMIgen_DEADBAND_COUNT         (*(reg8 *)  NMIgen_PWMUDB_genblk7_dbctrlreg__CONTROL_REG)
        #define NMIgen_DEADBAND_COUNT_PTR     ((reg8 *)   NMIgen_PWMUDB_genblk7_dbctrlreg__CONTROL_REG)
        #define NMIgen_DEADBAND_COUNT_MASK    (uint8)((uint8)0x03u << NMIgen_DEADBAND_COUNT_SHIFT)

        /* As defined by the verilog implementation of the Control Register */
        #define NMIgen_DEADBAND_COUNT_SHIFT   (0x00u)
    #endif /* (NMIgen_UsingFixedFunction) */
#endif /* (NMIgen_DeadBandMode == NMIgen__B_PWM__DBM_256_CLOCKS) */



#if (NMIgen_UsingFixedFunction)
    #define NMIgen_STATUS                 (*(reg8 *) NMIgen_PWMHW__SR0)
    #define NMIgen_STATUS_PTR             ((reg8 *) NMIgen_PWMHW__SR0)
    #define NMIgen_STATUS_MASK            (*(reg8 *) NMIgen_PWMHW__SR0)
    #define NMIgen_STATUS_MASK_PTR        ((reg8 *) NMIgen_PWMHW__SR0)
    #define NMIgen_CONTROL                (*(reg8 *) NMIgen_PWMHW__CFG0)
    #define NMIgen_CONTROL_PTR            ((reg8 *) NMIgen_PWMHW__CFG0)
    #define NMIgen_CONTROL2               (*(reg8 *) NMIgen_PWMHW__CFG1)
    #define NMIgen_CONTROL3               (*(reg8 *) NMIgen_PWMHW__CFG2)
    #define NMIgen_GLOBAL_ENABLE          (*(reg8 *) NMIgen_PWMHW__PM_ACT_CFG)
    #define NMIgen_GLOBAL_ENABLE_PTR      ( (reg8 *) NMIgen_PWMHW__PM_ACT_CFG)
    #define NMIgen_GLOBAL_STBY_ENABLE     (*(reg8 *) NMIgen_PWMHW__PM_STBY_CFG)
    #define NMIgen_GLOBAL_STBY_ENABLE_PTR ( (reg8 *) NMIgen_PWMHW__PM_STBY_CFG)


    /***********************************
    *          Constants
    ***********************************/

    /* Fixed Function Block Chosen */
    #define NMIgen_BLOCK_EN_MASK          (NMIgen_PWMHW__PM_ACT_MSK)
    #define NMIgen_BLOCK_STBY_EN_MASK     (NMIgen_PWMHW__PM_STBY_MSK)
    
    /* Control Register definitions */
    #define NMIgen_CTRL_ENABLE_SHIFT      (0x00u)

    /* As defined by Register map as MODE_CFG bits in CFG2*/
    #define NMIgen_CTRL_CMPMODE1_SHIFT    (0x04u)

    /* As defined by Register map */
    #define NMIgen_CTRL_DEAD_TIME_SHIFT   (0x06u)  

    /* Fixed Function Block Only CFG register bit definitions */
    /*  Set to compare mode */
    #define NMIgen_CFG0_MODE              (0x02u)   

    /* Enable the block to run */
    #define NMIgen_CFG0_ENABLE            (0x01u)   
    
    /* As defined by Register map as DB bit in CFG0 */
    #define NMIgen_CFG0_DB                (0x20u)   

    /* Control Register Bit Masks */
    #define NMIgen_CTRL_ENABLE            (uint8)((uint8)0x01u << NMIgen_CTRL_ENABLE_SHIFT)
    #define NMIgen_CTRL_RESET             (uint8)((uint8)0x01u << NMIgen_CTRL_RESET_SHIFT)
    #define NMIgen_CTRL_CMPMODE2_MASK     (uint8)((uint8)0x07u << NMIgen_CTRL_CMPMODE2_SHIFT)
    #define NMIgen_CTRL_CMPMODE1_MASK     (uint8)((uint8)0x07u << NMIgen_CTRL_CMPMODE1_SHIFT)

    /* Control2 Register Bit Masks */
    /* As defined in Register Map, Part of the TMRX_CFG1 register */
    #define NMIgen_CTRL2_IRQ_SEL_SHIFT    (0x00u)
    #define NMIgen_CTRL2_IRQ_SEL          (uint8)((uint8)0x01u << NMIgen_CTRL2_IRQ_SEL_SHIFT)

    /* Status Register Bit Locations */
    /* As defined by Register map as TC in SR0 */
    #define NMIgen_STATUS_TC_SHIFT        (0x07u)   
    
    /* As defined by the Register map as CAP_CMP in SR0 */
    #define NMIgen_STATUS_CMP1_SHIFT      (0x06u)   

    /* Status Register Interrupt Enable Bit Locations */
    #define NMIgen_STATUS_KILL_INT_EN_MASK_SHIFT          (0x00u)
    #define NMIgen_STATUS_TC_INT_EN_MASK_SHIFT            (NMIgen_STATUS_TC_SHIFT - 4u)
    #define NMIgen_STATUS_CMP2_INT_EN_MASK_SHIFT          (0x00u)
    #define NMIgen_STATUS_CMP1_INT_EN_MASK_SHIFT          (NMIgen_STATUS_CMP1_SHIFT - 4u)

    /* Status Register Bit Masks */
    #define NMIgen_STATUS_TC              (uint8)((uint8)0x01u << NMIgen_STATUS_TC_SHIFT)
    #define NMIgen_STATUS_CMP1            (uint8)((uint8)0x01u << NMIgen_STATUS_CMP1_SHIFT)

    /* Status Register Interrupt Bit Masks */
    #define NMIgen_STATUS_TC_INT_EN_MASK              (uint8)((uint8)NMIgen_STATUS_TC >> 4u)
    #define NMIgen_STATUS_CMP1_INT_EN_MASK            (uint8)((uint8)NMIgen_STATUS_CMP1 >> 4u)

    /*RT1 Synch Constants */
    #define NMIgen_RT1_SHIFT             (0x04u)

    /* Sync TC and CMP bit masks */
    #define NMIgen_RT1_MASK              (uint8)((uint8)0x03u << NMIgen_RT1_SHIFT)
    #define NMIgen_SYNC                  (uint8)((uint8)0x03u << NMIgen_RT1_SHIFT)
    #define NMIgen_SYNCDSI_SHIFT         (0x00u)

    /* Sync all DSI inputs */
    #define NMIgen_SYNCDSI_MASK          (uint8)((uint8)0x0Fu << NMIgen_SYNCDSI_SHIFT)

    /* Sync all DSI inputs */
    #define NMIgen_SYNCDSI_EN            (uint8)((uint8)0x0Fu << NMIgen_SYNCDSI_SHIFT)


#else
    #define NMIgen_STATUS                (*(reg8 *)   NMIgen_PWMUDB_genblk8_stsreg__STATUS_REG )
    #define NMIgen_STATUS_PTR            ((reg8 *)    NMIgen_PWMUDB_genblk8_stsreg__STATUS_REG )
    #define NMIgen_STATUS_MASK           (*(reg8 *)   NMIgen_PWMUDB_genblk8_stsreg__MASK_REG)
    #define NMIgen_STATUS_MASK_PTR       ((reg8 *)    NMIgen_PWMUDB_genblk8_stsreg__MASK_REG)
    #define NMIgen_STATUS_AUX_CTRL       (*(reg8 *)   NMIgen_PWMUDB_genblk8_stsreg__STATUS_AUX_CTL_REG)
    #define NMIgen_CONTROL               (*(reg8 *)   NMIgen_PWMUDB_genblk1_ctrlreg__CONTROL_REG)
    #define NMIgen_CONTROL_PTR           ((reg8 *)    NMIgen_PWMUDB_genblk1_ctrlreg__CONTROL_REG)


    /***********************************
    *          Constants
    ***********************************/

    /* Control Register bit definitions */
    #define NMIgen_CTRL_ENABLE_SHIFT      (0x07u)
    #define NMIgen_CTRL_RESET_SHIFT       (0x06u)
    #define NMIgen_CTRL_CMPMODE2_SHIFT    (0x03u)
    #define NMIgen_CTRL_CMPMODE1_SHIFT    (0x00u)
    #define NMIgen_CTRL_DEAD_TIME_SHIFT   (0x00u)   /* No Shift Needed for UDB block */
    
    /* Control Register Bit Masks */
    #define NMIgen_CTRL_ENABLE            (uint8)((uint8)0x01u << NMIgen_CTRL_ENABLE_SHIFT)
    #define NMIgen_CTRL_RESET             (uint8)((uint8)0x01u << NMIgen_CTRL_RESET_SHIFT)
    #define NMIgen_CTRL_CMPMODE2_MASK     (uint8)((uint8)0x07u << NMIgen_CTRL_CMPMODE2_SHIFT)
    #define NMIgen_CTRL_CMPMODE1_MASK     (uint8)((uint8)0x07u << NMIgen_CTRL_CMPMODE1_SHIFT)

    /* Status Register Bit Locations */
    #define NMIgen_STATUS_KILL_SHIFT          (0x05u)
    #define NMIgen_STATUS_FIFONEMPTY_SHIFT    (0x04u)
    #define NMIgen_STATUS_FIFOFULL_SHIFT      (0x03u)
    #define NMIgen_STATUS_TC_SHIFT            (0x02u)
    #define NMIgen_STATUS_CMP2_SHIFT          (0x01u)
    #define NMIgen_STATUS_CMP1_SHIFT          (0x00u)

    /* Status Register Interrupt Enable Bit Locations - UDB Status Interrupt Mask match Status Bit Locations*/
    #define NMIgen_STATUS_KILL_INT_EN_MASK_SHIFT          (NMIgen_STATUS_KILL_SHIFT)
    #define NMIgen_STATUS_FIFONEMPTY_INT_EN_MASK_SHIFT    (NMIgen_STATUS_FIFONEMPTY_SHIFT)
    #define NMIgen_STATUS_FIFOFULL_INT_EN_MASK_SHIFT      (NMIgen_STATUS_FIFOFULL_SHIFT)
    #define NMIgen_STATUS_TC_INT_EN_MASK_SHIFT            (NMIgen_STATUS_TC_SHIFT)
    #define NMIgen_STATUS_CMP2_INT_EN_MASK_SHIFT          (NMIgen_STATUS_CMP2_SHIFT)
    #define NMIgen_STATUS_CMP1_INT_EN_MASK_SHIFT          (NMIgen_STATUS_CMP1_SHIFT)

    /* Status Register Bit Masks */
    #define NMIgen_STATUS_KILL            (uint8)((uint8)0x00u << NMIgen_STATUS_KILL_SHIFT )
    #define NMIgen_STATUS_FIFOFULL        (uint8)((uint8)0x01u << NMIgen_STATUS_FIFOFULL_SHIFT)
    #define NMIgen_STATUS_FIFONEMPTY      (uint8)((uint8)0x01u << NMIgen_STATUS_FIFONEMPTY_SHIFT)
    #define NMIgen_STATUS_TC              (uint8)((uint8)0x01u << NMIgen_STATUS_TC_SHIFT)
    #define NMIgen_STATUS_CMP2            (uint8)((uint8)0x01u << NMIgen_STATUS_CMP2_SHIFT)
    #define NMIgen_STATUS_CMP1            (uint8)((uint8)0x01u << NMIgen_STATUS_CMP1_SHIFT)

    /* Status Register Interrupt Bit Masks  - UDB Status Interrupt Mask match Status Bit Locations */
    #define NMIgen_STATUS_KILL_INT_EN_MASK            (NMIgen_STATUS_KILL)
    #define NMIgen_STATUS_FIFOFULL_INT_EN_MASK        (NMIgen_STATUS_FIFOFULL)
    #define NMIgen_STATUS_FIFONEMPTY_INT_EN_MASK      (NMIgen_STATUS_FIFONEMPTY)
    #define NMIgen_STATUS_TC_INT_EN_MASK              (NMIgen_STATUS_TC)
    #define NMIgen_STATUS_CMP2_INT_EN_MASK            (NMIgen_STATUS_CMP2)
    #define NMIgen_STATUS_CMP1_INT_EN_MASK            (NMIgen_STATUS_CMP1)

    /* Datapath Auxillary Control Register bit definitions */
    #define NMIgen_AUX_CTRL_FIFO0_CLR         (0x01u)
    #define NMIgen_AUX_CTRL_FIFO1_CLR         (0x02u)
    #define NMIgen_AUX_CTRL_FIFO0_LVL         (0x04u)
    #define NMIgen_AUX_CTRL_FIFO1_LVL         (0x08u)
    #define NMIgen_STATUS_ACTL_INT_EN_MASK    (0x10u) /* As defined for the ACTL Register */
#endif /* NMIgen_UsingFixedFunction */

#endif  /* CY_PWM_NMIgen_H */


/* [] END OF FILE */
