/*******************************************************************************
* File Name: MPURR1_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "MPURR1.h"

/* Check for removal by optimization */
#if !defined(MPURR1_Sync_ctrl_reg__REMOVED)

static MPURR1_BACKUP_STRUCT  MPURR1_backup = {0u};

    
/*******************************************************************************
* Function Name: MPURR1_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void MPURR1_SaveConfig(void) 
{
    MPURR1_backup.controlState = MPURR1_Control;
}


/*******************************************************************************
* Function Name: MPURR1_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void MPURR1_RestoreConfig(void) 
{
     MPURR1_Control = MPURR1_backup.controlState;
}


/*******************************************************************************
* Function Name: MPURR1_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void MPURR1_Sleep(void) 
{
    MPURR1_SaveConfig();
}


/*******************************************************************************
* Function Name: MPURR1_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void MPURR1_Wakeup(void)  
{
    MPURR1_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
