/*******************************************************************************
* File Name: SyncCtrl_1_Sync_PM.c
* Version 1.0
*
* Description:
*  This file provides Low power mode APIs for Count7 component.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "SyncCtrl_1_Sync.h"


SyncCtrl_1_Sync_BACKUP_STRUCT SyncCtrl_1_Sync_backup;


/*******************************************************************************
* Function Name: SyncCtrl_1_Sync_SaveConfig
********************************************************************************
*
* Summary:
*  This function saves the component configuration and non-retention registers.
*  This function is called by the Count7_Sleep() function.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global Variables:
*  SyncCtrl_1_Sync_backup - used to save component configuration and non-
*  retention registers before enter sleep mode.
*
*******************************************************************************/
void SyncCtrl_1_Sync_SaveConfig(void) 
{
    SyncCtrl_1_Sync_backup.count = SyncCtrl_1_Sync_COUNT_REG;
}


/*******************************************************************************
* Function Name: SyncCtrl_1_Sync_Sleep
********************************************************************************
*
* Summary:
*  This is the preferred API to prepare the component for low power mode
*  operation. The Count7_Sleep() API saves the current component state using
*  Count7_SaveConfig() and disables the counter.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void SyncCtrl_1_Sync_Sleep(void) 
{
    if(0u != (SyncCtrl_1_Sync_AUX_CONTROL_REG & SyncCtrl_1_Sync_COUNTER_START))
    {
        SyncCtrl_1_Sync_backup.enableState = 1u;
        SyncCtrl_1_Sync_Stop();
    }
    else
    {
        SyncCtrl_1_Sync_backup.enableState = 0u;
    }

    SyncCtrl_1_Sync_SaveConfig();
}


/*******************************************************************************
* Function Name: SyncCtrl_1_Sync_RestoreConfig
********************************************************************************
*
* Summary:
*  This function restores the component configuration and non-retention
*  registers. This function is called by the Count7_Wakeup() function.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global Variables:
*  SyncCtrl_1_Sync_backup - used to save component configuration and
*  non-retention registers before exit sleep mode.
*
*******************************************************************************/
void SyncCtrl_1_Sync_RestoreConfig(void) 
{
    SyncCtrl_1_Sync_COUNT_REG = SyncCtrl_1_Sync_backup.count;
}


/*******************************************************************************
* Function Name: SyncCtrl_1_Sync_Wakeup
********************************************************************************
*
* Summary:
*  This is the preferred API to restore the component to the state when
*  Count7_Sleep() was called. The Count7_Wakeup() function calls the
*  Count7_RestoreConfig() function to restore the configuration.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void SyncCtrl_1_Sync_Wakeup(void) 
{
    SyncCtrl_1_Sync_RestoreConfig();

    /* Restore enable state */
    if (SyncCtrl_1_Sync_backup.enableState != 0u)
    {
        SyncCtrl_1_Sync_Enable();
    }
}


/* [] END OF FILE */
