// Grant Searle specific part

#include "project.h"
#include "common.h"

uint8 SIO_A[8],SIO_B[8];

#define OBUSY 0x00
#define OIDLE 0x04
#define INONE  0x00
#define IAVAIL 0x01

CY_ISR(GrantModeISR)
{
    //IORQn_ClearInterrupt();
    IORQn_INTSTAT;              // Clear on Read
    
    if ((M1_PS&M1_MASK)==0) {D_DR=SIO_B[2]; INTn_Write(1); Control_Control|=1; return; }
    
    io_ctrl=*(uint8*)CYREG_PRT0_PS;
    
    if ((io_ctrl&0x02)==0)      // Write IO
    {
        io_port=Al_PS; io_data=D_PS;
        
        switch (io_port)
        {
            case 0x00:
                ubuf[uptr++]=io_data;
                break;
            case 0x02:               
                if (SIO_A[0]&7) { SIO_A[SIO_A[0]&0x7]=io_data; SIO_A[0]&=0xF8; }
                           else { SIO_A[0]=io_data; }
                break;
            case 0x03:
                if (SIO_B[0]&7) { SIO_B[SIO_B[0]&0x7]=io_data; SIO_B[0]&=0xF8; }
                           else { SIO_B[0]=io_data; }
                break;
            case 0x01:
                break;
               
            case 0x11:
                if (io_data==0x01) sdcard_op=SD_OPEN;        
                break;
            case 0x12:
                //if (io_data!=1) {print("Rd/Wr > 1 sector"); CRLF; }
                break;
            case 0x13:
                cpm_offset=(cpm_offset&0xFFFE0000)|(io_data<<9);
                break;
            case 0x14:
                cpm_offset=(cpm_offset&0xFE01FE00)|(io_data<<17);
                break;
            case 0x15: // only 2 bits
                cpm_offset=(cpm_offset&0x01FFFE00)|((io_data&3)<<25);
                break;
            case 0x16:
                // Always E0
                break;
            case 0x17:
                if (io_data==0x20)
                 {//lstatus("Read @",cpm_offset);
                  sdcard_op=SD_READ;            
                 }
                else if (io_data==0x30)
                 { //lstatus("Pre_Write @",cpm_offset);
                  Rw_Ptr=0;
                 }
                break;
            case 0x10:
                rw_buf[Rw_Ptr++]=io_data;
                if (Rw_Ptr==512) { 
                 sdcard_op=SD_WRITE;
                }
                break;
                
            case 0x38:
                break;
                
            default:
                io_int=1;
        }
    }
    else if ((io_ctrl&0x01)==0)     // Read IO
    { 
        io_port=Al_PS;
        
        switch (io_port)
        {
            case 0x02:
                D_DR=obusy|ink;break;
            case 0x00:
                D_DR=key; ink=INONE;break;
            case 0x01:
                D_DR=0;break;
            case 0x03:
                D_DR=4;break;   // OIDLE ?
            
            case 0x17:
                D_DR=(sdcard_op==SD_IDLE)?0x00:0x80;
                break;          
            case 0x10:
                D_DR=rw_buf[Rw_Ptr++];
                if (Rw_Ptr>rdbytes) { //print("EoB");
                                      Rw_Ptr=0;}
                break;
                
            default:
                io_int=1;
        }
    }
    else
    {
        io_port=Al_PS; io_data=D_PS;
        io_int=1;
    }
    
    Control_Control|=1;
}

void GrantModeLoop(void)
{
    uint8 debug=0;

    ink=INONE;key=0;
    ubuf=wbuf;pbuf=rbuf;uptr=0;
    obusy=OIDLE;
    
    SIO_A[0]=0; SIO_B[0]=0;
    
    Control_Control|=1;     /* Reset Wait */
    CyDelay(1);RESETn_Write(1);
    
    do
    {
        if (debug){
            uprinth(Ah_PS);uprinth(Al_PS);uprintf(" ");uprinth(D_PS);uprintf(" ");uprinth(*(uint8*)CYREG_PRT0_PS);
            uprintf("\r");
        }
        
        if (io_int) {  IOint_Disable();
                       if ((io_ctrl&0x01)==0) {uprintf("\r\nInt : R");uprinth(io_port);uprinth(io_data);uprintf("\n\r");}
                       else if ((io_ctrl&0x02)==0) {uprintf("\r\nInt : W");uprinth(io_port);uprinth(io_data);uprintf("\n\r");}
                       else {uprintf("\r\nInt : ?");uprinth(io_ctrl);uprinth(io_port);uprinth(io_data);uprintf("\n\r");}
                       debug=1;
                       io_int=0;
                       IOint_Enable();
                    }
        
        if (sdcard_op==SD_READ) {
          resultF=f_lseek(&fileO,cpm_offset);
          if (resultF != RES_OK) {print("Read Seek not OK\n\r");}
          resultF=f_read(&fileO,rw_buf,512,&rdbytes); 
          if (resultF != RES_OK) {print("Read not OK\n\r");}
          Rw_Ptr=0; 
          sdcard_op=SD_IDLE;
        }
        if (sdcard_op==SD_WRITE) {            
          resultF=f_lseek(&fileO,cpm_offset);
          if (resultF != RES_OK) {print("Wr Seek not OK\n\r");}
          resultF=f_write(&fileO,rw_buf,512,&rdbytes);
          if (resultF != RES_OK) {print("Wr not OK\n\r");}
          Rw_Ptr=0;
          sdcard_op=SD_IDLE;
        }
        if (sdcard_op==SD_OPEN) {            
          resultF=f_open(&fileO,"cpm.bin",FA_READ|FA_WRITE);
          //if (resultF == RES_OK) { print("cpm.bin opened for RW Ok\n\r");
          //lstatus("File size ",f_size(&fileO));}
          sdcard_op=SD_IDLE;
        }

        if (uptr&&USBUART_CDCIsReady()) {char *tbuf; // Temp bufptr, for ptr swap
                                         IOint_Disable();ubuf[uptr]=0;
                                         tbuf=ubuf;ubuf=pbuf;pbuf=tbuf;
                                         uptr=0; obusy=OBUSY;
                                         IOint_Enable();
                                         uprintf(pbuf);vga_print(pbuf);
                                         obusy=OIDLE;
                                        }

        if ((key_avail)&&(!ink)) {key_read; key=kbuf[0]; ink=1; INTn_Write(0); }
        
    } while (key!='~');
}

sbc Grant={
    .sbc_bootfile="grant.bin",
    .sbc_dir="Grant",
    .sbc_name="Grant Searle Mode",
    .f_offset=0, .f_size=0, .loadaddr=0,
    .interrupt=GrantModeISR,
    .main_loop=GrantModeLoop
};

void GrantModeInit(void)
{
    CleanRestart();
    SBC=Grant;
}