/* ========================================
 *
 * PSoC5LP - Z80 - Interface
 *
 * Started 03/2018 - JJ Michel
 *
 * ========================================
*/
#include "project.h"
#define MAIN
#include "common.h"

FATFS fatFs;
uint8 resultF;

uint8 debug;

// Changed in IO interrupt
volatile uint8 io_int,io_port,io_data,io_ctrl;
volatile uint8 ink,key,obusy;
volatile uint8 sdcard_op;

char buffer[60];

FIL    fileO;
uint32 Rw_Ptr=0;
char   rw_buf[512];
uint   rdbytes;

uint32 cpm_offset;

//char filename[80];
//uint32 f_offset;
//uint16 f_size;
//char emul_name[80];
//void (*interrupt)(void);
//void (*main_loop)(void);

sbc SBC;

char rbuf[65],wbuf[65],*ubuf,*pbuf;     // Buffer for Char Output (from emulated uart to USB/VGA)
uint8 uptr;                             // ptr
uint8 kbuf[8];                          // Buffer for Char Input (from USB/PS2 to emulated uart)

void keyboard(void)
{
    do
    {
     if (ps2_available())
      printf("%c",ps2_read());
    } while (1==1);
    
}    

const char *bin2str[16] = { "0000","0001","0010","0011",
                            "0100","0101","0110","0111",
                            "1000","1001","1010","1011",
                            "1100","1101","1110","1111" };

int main(void)
{
    int i;
    unsigned char buf[64];
    
    CyGlobalIntEnable; /* Enable global interrupts. */

    /* All Inits */
    
    // USBUART
    USBUART_Start(0,USBUART_5V_OPERATION);    
    while (!USBUART_GetConfiguration()) ;    
    USBUART_CDC_Init();
    
    // SPI SDCARD
    SPIM_Start();
    
    // VGA
    vga_init();
    // PS2 Keyboard
    ps2_init();   
    
    GrantModeInit();   
    // INTERRUPT by IOREQ
    IOint_StartEx(SBC.interrupt);

reset:    
     uprintf("Started\n\r");
     CyDelay(1000);
    
    /* Mount sdcard. */
    resultF = f_mount(&fatFs, "", 1);
    
    if (resultF == RES_OK) 
    { print("SDCard Open Ok\n\r"); }
       
    for(;;)
    {
        RESETn_Write(0);
        
        uprintf("########\n\r# Menu #\n\r########\n\r\n\r");
        uprintf(" ROM FILE  : ");uprintf(SBC.sbc_bootfile);uprintf("\n\r");
        uprintf(" Emulation : ");uprintf(SBC.sbc_name);uprintf("\n\r\n\r");
// For Clean SD-Card -> Use chdir
        { char pathname[80];
          sprintf(pathname,"/psoc-z80/%s",SBC.sbc_dir); f_chdir(pathname);
        }
// Debug : list folder content
#if 0
        {
              FRESULT res;
              DIR dir;
              static FILINFO fno;


              res = f_opendir(&dir, ".");                       /* Open the directory */
              if (res == FR_OK) {
                for (;;) {
                    res = f_readdir(&dir, &fno);                   /* Read a directory item */
                    if (res != FR_OK || fno.fname[0] == 0) break;  /* Break on error or end of dir */
                    if (!(fno.fattrib & AM_DIR))  /* It is a file. */
                        uprintf(fno.fname); uprintf("\t");
                }
                uprintf("\r\n");
              }
            f_closedir(&dir);
        }
#endif
//
        uprintf(" - r : ROM/MON -> SRAM\n\r");
        uprintf(" - g : launch emulation\n\r");
        uprintf(" - t/d/z : memory test/dump/zero\n\r");
        uprintf(" - x : Reset PSoC\n\r");
    
        
        while ((i=USBUART_GetCount())==0) ;
        USBUART_GetData(buf,i);
        
        if (buf[0]=='g') {IOint_StartEx(SBC.interrupt); SBC.main_loop();}
        if (buf[0]=='r') sram_sendfile();
        if (buf[0]=='t') sram_test();
        if (buf[0]=='d') sram_read();
        if (buf[0]=='z') sram_zero();
        if (buf[0]=='x') goto reset;
        //if (buf[0]=='k') keyboard();  //Kbd test
        
        if (buf[0]=='1') GrantModeInit();
        if (buf[0]=='2') RC2014ModeInit();
        if (buf[0]=='3') RCSIOModeInit();
        if (buf[0]=='4') S100ModeInit();
        if (buf[0]=='5') MBC2ModeInit();
        // Tests
        if (buf[0]=='7') Cpm3ModeInit();
        if (buf[0]=='8') PacmanModeInit();
        if (buf[0]=='9') ZX81ModeInit();
    }
}

/* [] END OF FILE */
