
#include "project.h"

#include "common.h"

#include "font8x8.h"

/* Defines for DMA_1 */
#define DMA_1_BYTES_PER_BURST 2
#define DMA_1_REQUEST_PER_BURST 1
#define DMA_1_SRC_BASE (CYDEV_SRAM_BASE)
#define DMA_1_DST_BASE (CYDEV_PERIPH_BASE)

/* Variable declarations for DMA_1 */
/* Move these variable declarations to the top of the function */
uint8 DMA_1_Chan;
uint8 DMA_1_TD[1];

int vgacol,vgaln;
uint8 scr[60][80];
uint8 scr1_buf[8][80],scr2_buf[8][80];
uint8 *cur_scr,*next_scr;
uint8 next_line=0;

CY_ISR_PROTO(HsyncISR)
{
    uint16 vert;
    
    GP5_5_Write(1);
    
    vert=*VSyncCtrl_1_Datapath_1_A0_PTR;
    
    if (vert>19)
    {
      uint8 i,j,c;
      uint32 l;
        
      i=(499-vert)&7;
      CyDmaTdSetAddress(DMA_1_TD[0], LO16((uint32)cur_scr+i*80),
       LO16((uint32)shifter16_1_Datapath_1_u0__16BIT_F0_REG));
      CyDmaChEnable(DMA_1_Chan,1);

      uint8 *sptr,*fptr,*wptr;

      wptr=next_scr+i;
      sptr=scr[next_line]+i;
      for(j=0;j<10;j++)
      {
       c=*sptr;
       fptr=font8x8_basic[c];
#if 1
       // 7.9us instead of 8.9us
       l=*(uint32 *)fptr;
       wptr[  0]=l&0xFF; wptr[ 80]=(l&0xFF00)>>8; wptr[160]=(l&0xFF0000)>>16; wptr[240]=(l&0xFF000000)>>24;
       l=*(uint32 *)(fptr+4);
       wptr[320]=l&0xFF; wptr[400]=(l&0xFF00)>>8; wptr[480]=(l&0xFF0000)>>16; wptr[560]=(l&0xFF000000)>>24; 
#else
       wptr[  0]=*fptr++; wptr[ 80]=*fptr++; wptr[160]=*fptr++; wptr[240]=*fptr++;
       wptr[320]=*fptr++; wptr[400]=*fptr++; wptr[480]=*fptr++; wptr[560]=*fptr; 
#endif    
       wptr+=8;sptr+=8;
      }
      if (i==7) {
                 uint8 *tmp_ptr;
                 next_line++; if (next_line>59) next_line=0;
                 tmp_ptr=cur_scr;
                 cur_scr=next_scr;
                 next_scr=tmp_ptr;
                }
    }
    else
    {
      next_line=1;
    }
    
    GP5_5_Write(0);
}

void vga_init(void)
{
    int i,j;
    

    VSyncCtrl_1_Sync_Start();
    SyncCtrl_1_Sync_Start();
    shifter16_1_Count7_1_Start();

    // Test VGA   
    //for(i=0;i<8;i++)
    // for(j=0;j<80;j++)
    //  scr1_buf[i][j]=font8x8_basic[32+j][i];
    //
    //for(i=0;i<8;i++)  {scr1_buf[i][0]=0x01;scr1_buf[i][79]=0x80;}

    for(i=0;i<60;i++)
     for(j=0;j<80;j++)
       scr[i][j]=0x20;
    vgaln=0;vgacol=0;
    
    cur_scr=scr1_buf[0];
    next_scr=scr2_buf[0];
    
    DMA_1_Chan = DMA_1_DmaInitialize(DMA_1_BYTES_PER_BURST, DMA_1_REQUEST_PER_BURST, 
        HI16(DMA_1_SRC_BASE), HI16(DMA_1_DST_BASE));
    DMA_1_TD[0] = CyDmaTdAllocate();
    CyDmaTdSetConfiguration(DMA_1_TD[0], 80, CY_DMA_DISABLE_TD,
      CY_DMA_TD_INC_SRC_ADR|DMA_1__TD_TERMOUT_EN);
    CyDmaTdSetAddress(DMA_1_TD[0], LO16((uint32)scr1_buf[0]),
      LO16((uint32)shifter16_1_Datapath_1_u0__16BIT_F0_REG));
    CyDmaChSetInitialTd(DMA_1_Chan, DMA_1_TD[0]);
    CyDmaChEnable(DMA_1_Chan,1);

    isr_1_StartEx(HsyncISR);
}

void scroll(void)
{
    memcpy(scr[0],scr[1],59*80);        // Dest,Src,Bytes
    memset(scr[59],0x20,80);            // Dest,value,count
}

#define ESCAPE  0x01
#define BRACKET 0x02
char statebuf[20];
uint8 stateptr=0;

void evalvt(void)
{
    statebuf[stateptr]=0;
    
    if ((statebuf[0]=='[')&&((statebuf[stateptr-1]=='H')||(statebuf[stateptr-1]=='f')))
    { if (stateptr>3) {sscanf((char*)statebuf+1,"%d;%d",&vgaln,&vgacol);
                       vgaln--;vgacol--;}
                else {vgacol=0;vgaln=0;}
    }
    else if (strcmp(statebuf,"[2J")==0) memset(scr[0],0x20,60*80);
    
    else
     printf("VT:'%s'",statebuf);
    
    stateptr=0;
}    

void vga_print(char *ptr)
{
    char i;
    static uint8 state=0;
    
    while ((i=*ptr++)!=0)
    {
     if ((i>=32)&&(i<128))
      {
       if (state)
        {
            statebuf[stateptr++]=i;
            if (i=='[') state|=BRACKET;
            if ((i>'a')&&(i<'z')) {evalvt();state=0;}
            if ((i>'A')&&(i<'Z')) {evalvt();state=0;}
            if ((i>'0')&&(i<'9')&&((state&BRACKET)==0)) {evalvt();state=0;}
        }
       else
        {
         if (vgacol>=80) {vgacol=0;
                         if (vgaln<59) vgaln++; else scroll();}
        
         scr[vgaln][vgacol++]=i;
        }
      }
     else
      {
       if (i==13) vgacol=0;
       if (i==10) {if (vgaln<59) vgaln++; else scroll();}
       if (i==27) {state|=ESCAPE;}
      }    
    }
}

/* [] END OF FILE */
