#include "common.h"

// TEST ONLY
// Output is a .vcd file (using Teraterm logging) to display via GTKWave
//
// ROM is loaded at 0x8000,
// Then MPURR are configured to have 0x0000-0x7FFF = 0x8000-0xFFFF
// D-FILE is executed with bit 15 set => at address >0xc000

volatile uint8 debug=0;

CY_ISR(ZX81ModeISR)
{
    //IORQn_ClearInterrupt();
    IORQn_INTSTAT;              // Clear on Read
    
    if ((M1_PS&M1_MASK)==0) {INTn_Write(1); Control_Control|=1; return; }
    
    io_ctrl=*(uint8*)CYREG_PRT0_PS;
    
    if ((io_ctrl&0x02)==0)      // Write IO
    {
        io_port=Al_PS; io_data=D_PS;
        
        switch (io_port)
        {
            case 0xFD:
                // NMI Off
                break;
            case 0xFE:
                // NMI On
                break;
            case 0xFF:
                debug++; if(debug>1) Clock_1_SetDivider(60000);
                break;
                
            default:
                io_int=1;
        }
    }
    else if ((io_ctrl&0x01)==0)     // Read IO
    { 
        io_port=Al_PS;
        
        switch (io_port)
        {
            case 0xFE:
                D_DR=0xFF;break;
            
            default:
                io_int=1;
        }
    }
    else
    {
        io_port=Al_PS; io_data=D_PS;
        io_int=1;
    }
    
    Control_Control|=1;
}

void ZX81ModeLoop(void)
{
    uint8 i;
    uint8 buf[64];
    char *tbuf,*pbuf;

    uint32 ts=0;
    uint16 oaddr=0;
    uint8 odata=0,d;
    uint8 ord=0,owr=0,oio=0,omem=0,oclk=0,om1=0,orf=0,ohalt=0,onmi=0;
    
    char logbuf[80];
    
    debug=0;

    // CLK driven by DR, not by hardware Clock_1 (Clock_1_Stop useless ?)
    //Clock_1_Stop();   
    //*(uint8*)CYREG_PRT12_BYP&=~0x20;         // CLK on P12[5]

    // Bank select : lower 32k and upper 32k should be same (ghost)
    MPURR0_Write(0x02);
    MPURR1_Write(0x03);
    
    ink=0;key=0;ubuf=wbuf;pbuf=rbuf;uptr=0;

    uprintf("$date\r\nSeptember 18, 2018.\r\n$end\r\n");
    uprintf("$version\r\nPSOC5-Z80\r\n$end\r\n");
    uprintf("$comment\r\nAny comment text.\r\n$end\r\n");
    uprintf("$timescale 1ps $end\r\n");
    uprintf("$scope module logic $end\r\n");
    uprintf("$var wire 16 # address $end\r\n");
    uprintf("$var wire 8 $ data $end\r\n");
    //uprintf("$var wire 8 % control $end\r\n");
    //uprintf("$var wire 8 & clock $end\r\n");
    uprintf("$var wire 1 A rd $end\r\n");
    uprintf("$var wire 1 B wr $end\r\n");
    uprintf("$var wire 1 C iorq $end\r\n");
    uprintf("$var wire 1 D memrq $end\r\n");
    uprintf("$var wire 1 E clk $end\r\n");
    uprintf("$var wire 1 F m1 $end\r\n");
    uprintf("$var wire 1 G rfsh $end\r\n");
    uprintf("$var wire 1 H halt $end\r\n");
    uprintf("$var wire 1 I nmi $end\r\n");
    uprintf("$upscope $end\r\n");
    uprintf("$enddefinitions $end\r\n");
    uprintf("$dumpvars\r\n");
    uprintf("bxxxxxxxxxxxxxxxx #\r\n");
    uprintf("bxxxxxxxx $\r\n");
    uprintf("$end\r\n");
    
    Control_Control|=1;     /* Reset Wait */
    CyDelay(1);RESETn_Write(1);
    do
    {        
        if ( (debug>1) || ((GP5_PS&0x20)==0) ){          
          d=*(uint8*)CYREG_PRT12_PS;
          if ( ((d&0x20)!=oclk)|| ((GP5_PS&0x20)==0) ) {
            sprintf(logbuf,"#%ld\r\n",ts++);
            if (((Ah_PS<<8)+Al_PS)!=oaddr) {oaddr=(Ah_PS<<8)+Al_PS; 
                                           sprintf(logbuf+strlen(logbuf),"b%s%s%s%s #\r\n",bin2str[Ah_PS>>4],bin2str[Ah_PS&15],
                                                                                           bin2str[Al_PS>>4],bin2str[Al_PS&15]);}                                                                    
            if (D_PS!=odata) {odata=D_PS; sprintf(logbuf+strlen(logbuf),"b%s%s $\r\n",bin2str[D_PS>>4],bin2str[D_PS&15]);}
            
            d=*(uint8*)CYREG_PRT0_PS;
            if ((d&1)!=ord) {ord=d&1; sprintf(logbuf+strlen(logbuf),"%cA\r\n",(d&1)?'1':'0');}
            if ((d&2)!=owr) {owr=d&2; sprintf(logbuf+strlen(logbuf),"%cB\r\n",(d&2)?'1':'0');}
            if ((d&4)!=oio) {oio=d&4; sprintf(logbuf+strlen(logbuf),"%cC\r\n",(d&4)?'1':'0');}
            if ((d&8)!=omem) {omem=d&8; sprintf(logbuf+strlen(logbuf),"%cD\r\n",(d&8)?'1':'0');}

            d=*(uint8*)CYREG_PRT12_PS;
            if ((d&0x20)!=oclk) {oclk=d&0x20; sprintf(logbuf+strlen(logbuf),"%cE\r\n",(d&0x20)?'1':'0');}            
            if ((d&0x40)!=om1) {om1=d&0x40; sprintf(logbuf+strlen(logbuf),"%cF\r\n",(d&0x40)?'1':'0');}
            if ((d&0x80)!=orf) {orf=d&0x80; sprintf(logbuf+strlen(logbuf),"%cG\r\n",(d&0x80)?'1':'0');}

            d=*(uint8*)CYREG_PRT1_PS;
            if ((d&0x80)!=ohalt) {ohalt=d&0x80; sprintf(logbuf+strlen(logbuf),"%cH\r\n",(d&0x80)?'1':'0');}            

            d=*(uint8*)CYREG_PRT15_PS;
            if ((d&0x10)!=onmi) {onmi=d&0x10; sprintf(logbuf+strlen(logbuf),"%cI\r\n",(d&0x10)?'1':'0');}            

            
            print(logbuf);            
          }
        }
        
        if (io_int) {  IOint_Disable();
                       if ((io_ctrl&0x01)==0) {uprintf("\r\nInt : R");uprinth(io_port);uprinth(io_data);uprintf("\n\r");}
                       else if ((io_ctrl&0x02)==0) {uprintf("\r\nInt : W");uprinth(io_port);uprinth(io_data);uprintf("\n\r");}
                       else {uprintf("\r\nInt : ?");uprinth(io_ctrl);uprinth(io_port);uprinth(io_data);uprintf("\n\r");}
                       debug++;
                       io_int=0;
                       IOint_Enable();
                    }
        
        if (uptr&&USBUART_CDCIsReady()) {IOint_Disable();ubuf[uptr]=0;
                                         tbuf=ubuf;ubuf=pbuf;pbuf=tbuf;
                                         uptr=0;IOint_Enable();
                                         uprintf(pbuf);}

        if ((i=USBUART_GetCount())) {USBUART_GetData(buf,i);ink=1; key=buf[0];
                                     INTn_Write(0);}
    } while (key!='~');
}

sbc ZX81={
    .sbc_dir="ZX81",
    .sbc_bootfile="zx81.rom",
    .sbc_name="ZX81 Test Mode",
    .f_offset=0, .f_size=0, .loadaddr=0x8000,
    .interrupt=ZX81ModeISR,
    .main_loop=ZX81ModeLoop
};

void ZX81ModeInit(void)
{
    CleanRestart();
    SBC=ZX81;
}